summaryrefslogtreecommitdiffstats
path: root/vpp-common/vpp-translate-test
diff options
context:
space:
mode:
authorMaros Marsalek <mmarsale@cisco.com>2016-11-10 13:31:25 +0100
committerMarek Gradzki <mgradzki@cisco.com>2016-11-19 21:29:39 +0100
commit175197da8ea43335df3daeba4c6296fcd83a057c (patch)
tree110298a990c6191933c2ad65d1a06333bab76cee /vpp-common/vpp-translate-test
parent1813bf59fa53e8eb913d34b212d45b227dead799 (diff)
Post split cleanup
- change groupIds - change packages - update poms Change-Id: I343c5a292a67de1dd50687870ca4ab5b7276e93e Signed-off-by: Maros Marsalek <mmarsale@cisco.com> Signed-off-by: Marek Gradzki <mgradzki@cisco.com>
Diffstat (limited to 'vpp-common/vpp-translate-test')
-rw-r--r--vpp-common/vpp-translate-test/pom.xml5
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/JvppDumpExecutorTest.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/JvppDumpExecutorTest.java)4
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ListReaderCustomizerTest.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ListReaderCustomizerTest.java)2
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ReaderCustomizerTest.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ReaderCustomizerTest.java)6
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/FutureProducer.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/FutureProducer.java)2
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/InterfaceDumpHelper.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/InterfaceDumpHelper.java)2
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/NamingContextHelper.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/NamingContextHelper.java)4
-rw-r--r--vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/write/WriterCustomizerTest.java (renamed from vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/write/WriterCustomizerTest.java)6
8 files changed, 15 insertions, 16 deletions
diff --git a/vpp-common/vpp-translate-test/pom.xml b/vpp-common/vpp-translate-test/pom.xml
index 4dff6183d..e3fb45bbb 100644
--- a/vpp-common/vpp-translate-test/pom.xml
+++ b/vpp-common/vpp-translate-test/pom.xml
@@ -18,14 +18,13 @@
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
<parent>
- <groupId>io.fd.honeycomb.vpp</groupId>
+ <groupId>io.fd.hc2vpp.common</groupId>
<artifactId>vpp-impl-parent</artifactId>
<version>1.16.12-SNAPSHOT</version>
<relativePath>../../vpp-common/vpp-impl-parent</relativePath>
</parent>
<modelVersion>4.0.0</modelVersion>
- <groupId>io.fd.honeycomb.vpp</groupId>
<artifactId>vpp-translate-test</artifactId>
<version>1.16.12-SNAPSHOT</version>
<packaging>bundle</packaging>
@@ -36,7 +35,7 @@
<dependencies>
<dependency>
- <groupId>io.fd.honeycomb.vpp</groupId>
+ <groupId>${project.groupId}</groupId>
<artifactId>naming-context-api</artifactId>
<version>${project.version}</version>
</dependency>
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/JvppDumpExecutorTest.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/JvppDumpExecutorTest.java
index 500c31387..1259e89c8 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/JvppDumpExecutorTest.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/JvppDumpExecutorTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.read;
+package io.fd.hc2vpp.common.test.read;
import static org.mockito.Matchers.anyLong;
import static org.mockito.Matchers.eq;
@@ -23,7 +23,7 @@ import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import io.fd.honeycomb.translate.util.read.cache.EntityDumpExecutor;
-import io.fd.honeycomb.vpp.test.util.FutureProducer;
+import io.fd.hc2vpp.common.test.util.FutureProducer;
import io.fd.vpp.jvpp.VppInvocationException;
import io.fd.vpp.jvpp.core.future.FutureJVppCore;
import java.util.concurrent.CompletableFuture;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ListReaderCustomizerTest.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ListReaderCustomizerTest.java
index 8917c02db..3c11b2d3c 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ListReaderCustomizerTest.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ListReaderCustomizerTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.read;
+package io.fd.hc2vpp.common.test.read;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.verify;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ReaderCustomizerTest.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ReaderCustomizerTest.java
index d4cb385c6..d403dce55 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/read/ReaderCustomizerTest.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/read/ReaderCustomizerTest.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.read;
+package io.fd.hc2vpp.common.test.read;
import static org.junit.Assert.assertNotNull;
import static org.mockito.Mockito.mock;
@@ -26,8 +26,8 @@ import io.fd.honeycomb.translate.read.ReadContext;
import io.fd.honeycomb.translate.spi.read.ReaderCustomizer;
import io.fd.honeycomb.translate.read.ReadContext;
import io.fd.honeycomb.translate.spi.read.ReaderCustomizer;
-import io.fd.honeycomb.vpp.test.util.FutureProducer;
-import io.fd.honeycomb.vpp.test.util.NamingContextHelper;
+import io.fd.hc2vpp.common.test.util.FutureProducer;
+import io.fd.hc2vpp.common.test.util.NamingContextHelper;
import java.lang.reflect.Method;
import org.junit.Before;
import org.junit.Test;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/FutureProducer.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/FutureProducer.java
index a75b3c0ab..2bedb9507 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/FutureProducer.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/FutureProducer.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.util;
+package io.fd.hc2vpp.common.test.util;
import java.util.concurrent.CompletableFuture;
import javax.annotation.Nonnull;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/InterfaceDumpHelper.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/InterfaceDumpHelper.java
index c88ad3f44..81d29c8f4 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/InterfaceDumpHelper.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/InterfaceDumpHelper.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.util;
+package io.fd.hc2vpp.common.test.util;
import static org.mockito.Matchers.any;
import static org.mockito.Mockito.when;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/write/WriterCustomizerTest.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/write/WriterCustomizerTest.java
index 900418c4c..7067a0c39 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/write/WriterCustomizerTest.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/write/WriterCustomizerTest.java
@@ -14,14 +14,14 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.write;
+package io.fd.hc2vpp.common.test.write;
import io.fd.honeycomb.translate.MappingContext;
import io.fd.honeycomb.translate.ModificationCache;
import io.fd.honeycomb.translate.spi.write.WriterCustomizer;
import io.fd.honeycomb.translate.write.WriteContext;
-import io.fd.honeycomb.vpp.test.util.FutureProducer;
-import io.fd.honeycomb.vpp.test.util.NamingContextHelper;
+import io.fd.hc2vpp.common.test.util.FutureProducer;
+import io.fd.hc2vpp.common.test.util.NamingContextHelper;
import org.junit.Before;
import org.mockito.Mock;
import org.mockito.Mockito;
diff --git a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/NamingContextHelper.java b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/NamingContextHelper.java
index 9fc9cd457..719339cbf 100644
--- a/vpp-common/vpp-translate-test/src/main/java/io/fd/honeycomb/vpp/test/util/NamingContextHelper.java
+++ b/vpp-common/vpp-translate-test/src/main/java/io/fd/hc2vpp/common/test/util/NamingContextHelper.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package io.fd.honeycomb.vpp.test.util;
+package io.fd.hc2vpp.common.test.util;
import static org.mockito.Mockito.doReturn;
@@ -35,7 +35,7 @@ import org.opendaylight.yangtools.yang.binding.InstanceIdentifier;
import org.opendaylight.yangtools.yang.binding.KeyedInstanceIdentifier;
/**
* Utility that helps stubbing {@link io.fd.honeycomb.translate.vpp.util.NamingContext} methods.
*/
// TODO(HONEYCOMB-226): the class needs to be refactored or even removed after extracting interface from NamingContext
public interface NamingContextHelper {
@@ -35,7 +35,7 @@ import org.opendaylight.yangtools.yang.binding.InstanceIdentifier;
import org.opendaylight.yangtools.yang.binding.KeyedInstanceIdentifier;
/**
- * Utility that helps stubbing {@link io.fd.honeycomb.translate.vpp.util.NamingContext} methods.
+ * Utility that helps stubbing {@link io.fd.hc2vpp.common.translate.util.NamingContext} methods.
*/
// TODO(HONEYCOMB-226): the class needs to be refactored or even removed after extracting interface from NamingContext